@@ -26,7 +26,7 @@ def bar(it, label='', width=32, hide=False, empty_char='-', filled_char='='):
         x = int(width*_i/count)
         if not hide:
             STREAM.write(BAR_TEMPLATE % (
-                label, bar_filled_char*x, bar_empty_char*(width-x), _i, count))
+                label, filled_char*x, empty_char*(width-x), _i, count))
             STREAM.flush()
 
     count = len(it)
